@@ -227,16 +227,20 @@ def _response_hook(resp, *args, **kwargs):
     if content_type == "application/json":
         result = resp.json()
 
-        if "data" in result and isinstance(result["data"], list):
-            resp.result = result
-            resp.count = len(result["data"])
-        elif "count" in result and isinstance(result["count"], int):
-            resp.count = result["count"]
+        if isinstance(result, dict):
+            if "data" in result and isinstance(result["data"], list):
+                resp.result = result
+                resp.count = len(result["data"])
+            elif "count" in result and isinstance(result["count"], int):
+                resp.count = result["count"]
 
-        if "warning" in result:
-            logger.warning(result["warning"])
-        elif "error" in result and isinstance(result["error"], str):
-            logger.error(result["error"][:10000] + "...")
+            if "warning" in result:
+                logger.warning(result["warning"])
+            elif "error" in result and isinstance(result["error"], str):
+                logger.error(result["error"][:10000] + "...")
+        elif isinstance(result, list):
+            resp.result = result
+            resp.count = len(result)
 
     elif content_type == "application/gzip":
         resp.result = resp.content
@@ -720,17 +724,102 @@ class Client(SwaggerClient):
         setattr(future, "track_id", track_id)
         return future
 
-    def get_project(self, name: str = None) -> Type[Dict]:
-        """Retrieve full project entry
+    def available_query_params(self, resource="contributions"):
+        resources = self.swagger_spec.resources
+        resource_obj = resources.get(resource)
+        if not resource_obj:
+            available_resources = list(resources.keys())
+            logger.error(f"Choose one of {available_resources}!")
+            return
+
+        op_key = f"query{resource.capitalize()}"
+        operation = resource_obj.operations[op_key]
+        return [param.name for param in operation.params.values()]
+
+    def get_project(self, name: str = None, fields: list = None) -> Type[Dict]:
+        """Retrieve a project entry
 
         Args:
             name (str): name of the project
+            fields (list): list of fields to include in response
         """
         name = self.project or name
         if not name:
             return {"error": "initialize client with project or set `name` argument!"}
 
-        return Dict(self.projects.getProjectByName(pk=name, _fields=["_all"]).result())
+        fields = fields or ["_all"]  # retrieve all fields by default
+        return Dict(self.projects.getProjectByName(pk=name, _fields=fields).result())
+
+    def query_projects(
+        self,
+        query: dict = None,
+        term: str = None,
+        fields: list = None,
+        sort: str = None,
+        timeout: int = -1
+    ) -> List[dict]:
+        """Query projects by query and/or term (Atlas Search)
+
+        See `client.available_query_params(resource="projects")` for keyword arguments used in
+        query. Provide `term` to search for a term across all text fields in the project infos.
+
+        Args:
+            query (dict): optional query to select projects
+            term (str): optional term to search text fields in projects
+            fields (list): list of fields to include in response
+            sort (str): field to sort by; prepend +/- for asc/desc order
+            timeout (int): cancel remaining requests if timeout exceeded (in seconds)
+
+        Returns:
+            List of projects
+        """
+        query = query or {}
+
+        if self.project or "name" in query:
+            return self.get_project(name=query.get("name"), fields=fields)
+
+        if term:
+            def search_future(search_term):
+                future = self.session.get(
+                    f"{self.url}/projects/search",
+                    headers=self.headers,
+                    hooks={'response': _response_hook},
+                    params={"term": search_term},
+                )
+                setattr(future, "track_id", "search")
+                return future
+
+            responses = _run_futures([search_future(term)], timeout=timeout, disable=True)
+            query["name__in"] = responses["search"].get("result", [])
+
+        if fields:
+            query["_fields"] = fields
+        if sort:
+            query["_sort"] = sort
+
+        ret = self.projects.queryProjects(**query).result()  # first page
+        total_count, total_pages = ret["total_count"], ret["total_pages"]
+
+        if total_pages < 2:
+            return ret["data"]
+
+        for field in ["name__in", "_fields"]:
+            if field in query:
+                query[field] = ",".join(query[field])
+
+        queries = []
+
+        for page in range(2, total_pages+1):
+            queries.append(deepcopy(query))
+            queries[-1]["page"] = page
+
+        futures = [self._get_future(i, q, rel_url="projects") for i, q in enumerate(queries)]
+        responses = _run_futures(futures, total=total_count, timeout=timeout)
+
+        for resp in responses.values():
+            ret["data"] += resp["result"]["data"]
+
+        return ret["data"]
 
     def create_project(self, name: str, title: str, authors: str, description: str, url: str):
         """Create a project
@@ -1081,31 +1170,21 @@ class Client(SwaggerClient):
 
         return result["total_count"], result["total_pages"]
 
-    def get_unique_identifiers_flags(self, projects: list = None) -> dict:
-        """Retrieve values for `unique_identifiers` flags for a list of projects
+    def get_unique_identifiers_flags(self, query: dict = None) -> dict:
+        """Retrieve values for `unique_identifiers` flags.
+
+        See `client.available_query_params(resource="projects")` for available query parameters.
 
         Args:
-            projects (list): list of project names - return all if not set
+            query (dict): query to select projects
 
         Returns:
             {"<project-name>": True|False, ...}
         """
-        unique_identifiers, query = {}, {}
-
-        if projects:
-            query = {"name__in": projects}
-        elif self.project:
-            query = {"name": self.project}
-
-        resp = self.projects.queryProjects(
-            _fields=["name", "unique_identifiers"], **query
-        ).result()
-
-        for project in resp["data"]:
-            project_name = project["name"]
-            unique_identifiers[project_name] = project["unique_identifiers"]
-
-        return unique_identifiers
+        return {
+            p["name"]: p["unique_identifiers"]
+            for p in self.query_projects(query=query, fields=["name", "unique_identifiers"])
+        }
 
     def get_all_ids(
         self,
@@ -1277,7 +1356,7 @@ class Client(SwaggerClient):
     ) -> List[dict]:
         """Query contributions
 
-        See `client.contributions.queryContributions()` for keyword arguments used in query.
+        See `client.available_query_params()` for keyword arguments used in query.
 
         Args:
             query (dict): optional query to select contributions
@@ -1332,7 +1411,7 @@ class Client(SwaggerClient):
     ) -> dict:
         """Apply the same update to all contributions in a project (matching query)
 
-        See `client.contributions.queryContributions()` for keyword arguments used in query.
+        See `client.available_query_params()` for keyword arguments used in query.
 
         Args:
             data (dict): update to apply on every matching contribution
@@ -1561,7 +1640,7 @@ class Client(SwaggerClient):
         project_names = list(project_names)
 
         if not skip_dupe_check and len(collect_ids) != len(contributions):
-            unique_identifiers = self.get_unique_identifiers_flags(projects=project_names)
+            unique_identifiers = self.get_unique_identifiers_flags({"name__in": project_names})
             existing = defaultdict(dict, self.get_all_ids(
                 dict(project__in=project_names), include=COMPONENTS, timeout=timeout
             ))
